import * as React from "react";
import { RouterProps } from "react-router";
import "url-search-params-polyfill";
import { ThemeContext } from "./context";
import { Shop, Template, LinkList, Filters, Form, Breadcrumbs, Search } from "./types";
import { Cart, Helpers, Notifications, Wishlist } from "./helpers";
import * as Components from "./components";
import * as Utils from "./utils";
export declare class ShopifyNext {
    options: ShopifyNext.Options;
    static Context: React.Context<ThemeContext.Store>;
    static Components: typeof Components;
    static Utils: typeof Utils;
    static Cart: Cart;
    static Wishlist: Wishlist;
    static Notifications: Notifications;
    static Helpers: Helpers;
    constructor(options: ShopifyNext.Options);
    element(data?: any): JSX.Element;
    bootstrap(element: string, window?: any): void;
    private parse;
    private parseShopifyData;
    private parseShopifySections;
}
export declare namespace ShopifyNext {
    interface Templates {
        notFound: typeof React.Component;
        account: {
            activate: typeof React.Component;
            addresses: typeof React.Component;
            details: typeof React.Component;
            login: typeof React.Component;
            logout: typeof React.Component;
            order: typeof React.Component;
            register: typeof React.Component;
            reset: typeof React.Component;
        };
        article: typeof React.Component;
        blog: typeof React.Component;
        cart: typeof React.Component;
        checkout: typeof React.Component;
        collection: typeof React.Component;
        collections: typeof React.Component;
        giftcard: typeof React.Component;
        wishlist: typeof React.Component;
        home: typeof React.Component;
        page: typeof React.Component;
        password: typeof React.Component;
        product: typeof React.Component;
        search: typeof React.Component;
    }
    interface Props<ShopifyData = any> extends RouterProps {
        data: ShopifyData;
        sections: Array<typeof React.Component>;
        templates: ShopifyNext.Templates;
    }
    interface State {
        cart?: any;
        error?: any;
    }
    interface Data<SectionData = any, SettingsData = any> {
        article: any;
        blog: any;
        blogs: any;
        breadcrumbs: Breadcrumbs;
        cart: any;
        collection: any;
        collections: any;
        customer: any;
        filters: Filters;
        form: Form;
        linklist: LinkList;
        locales: any;
        order: any;
        orders: any;
        page: any;
        product: any;
        paginate: any;
        search: Search;
        section: SectionData;
        sections: any;
        settings: SettingsData;
        wishlist: any;
        shop: Shop;
        template: Template;
    }
    interface Section<Settings = any> {
        id: string;
        name: string;
        type: string;
        settings: Settings;
        blocks: Array<any>;
    }
    interface Notifications extends Notifications.Messages {
    }
    interface Options {
        templates: ShopifyNext.Templates;
        sections: Array<typeof React.Component>;
        notifications: ShopifyNext.Notifications;
    }
}
